==> scipion-em-locscale-1.0.3.tar.gz: scipion-em-locscale-1.0.3/locscale/constants.py <==

# **************************************************************************
# *
# * Authors:    Yunior C. Fonseca Reyna (cfonseca@cnb.csic.es)
# *
# * Unidad de  Bioinformatica of Centro Nacional de Biotecnologia , CSIC
# *
# * This program is free software; you can redistribute it and/or modify
# * it under the terms of the GNU General Public License as published by
# * the Free Software Foundation; either version 2 of the License, or
# * (at your option) any later version.
# *
# * This program is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# * GNU General Public License for more details.
# *
# * You should have received a copy of the GNU General Public License
# * along with this program; if not, write to the Free Software
# * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
# * 02111-1307  USA
# *
# *  All comments concerning this program package may be sent to the
# *  e-mail address 'scipion@cnb.csic.es'
# *
# **************************************************************************

from pyworkflow.utils import importFromPlugin


# we declarate global constants to multiple usage
LOCSCALE_HOME_VAR = 'LOCSCALE_HOME'
LOCSCALE_EMAN_HOME_VAR = 'LOCSCALE_EMAN_HOME'

EMAN_HOME_DEFAULT = "eman-2.12"  # FIXME: it should be
                                 #  importFromPlugin('eman2', 'Plugin').getHome()
                                 #  but 2.21 fails with MPI...

# Supported versions
V0_1 = '0.1'

# Existing eman versions
V2_11 = '2.11'
V2_12 = '2.12'
V2_21 = '2.21'

==> scipion-em-locscale-1.0.5.tar.gz: scipion-em-locscale-1.0.5/locscale/constants.py <==

# **************************************************************************
# *
# * Authors:    Yunior C. Fonseca Reyna (cfonseca@cnb.csic.es)
# *
# * Unidad de  Bioinformatica of Centro Nacional de Biotecnologia , CSIC
# *
# * This program is free software; you can redistribute it and/or modify
# * it under the terms of the GNU General Public License as published by
# * the Free Software Foundation; either version 2 of the License, or
# * (at your option) any later version.
# *
# * This program is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# * GNU General Public License for more details.
# *
# * You should have received a copy of the GNU General Public License
# * along with this program; if not, write to the Free Software
# * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
# * 02111-1307  USA
# *
# *  All comments concerning this program package may be sent to the
# *  e-mail address 'scipion@cnb.csic.es'
# *
# **************************************************************************

from pyworkflow.utils import importFromPlugin


LOCSCALE_HOME = 'LOCSCALE_HOME'

# --- Eman2 dependencies ---
emanPlugin = importFromPlugin('eman2', 'Plugin')

# to set the Eman2 environ in a bash-shell
EMAN_ENV_STR = ' '.join(['%s=%s' % (var, emanPlugin.getEnviron()[var])
                         for var in ('PATH', 'PYTHONPATH', 'LD_LIBRARY_PATH',
                                     'SCIPION_MPI_FLAGS')])


# Supported versions
V0_1 = '0.1'

# Existing eman versions
V2_21 = '2.21'
V2_3 = '2.3'
